@@ -67,7 +67,7 @@ class FixedWidthField(object):
     def to_python(self, val):
         if val is None:
             return val
-        return str(val)
+        return str(val).rstrip()
 
     def to_record(self, val):
         if val is None:
@@ -151,12 +151,22 @@ class ListField(FixedWidthField):
         self.record_class = record
         super(ListField, self).__init__(length)
 
+    def _get_records_from_string(self, val):
+        records = []
+        record_len = len(self.record_class)
+        for _ in range(self.length):
+            records.append(self.record_class.from_record(val[:record_len]))
+            val = val[record_len:]
+        return records
+
     def to_python(self, val):
         """
         the python representation should be a list of instantiated
         Record classes.
         """
-        if not all([isinstance(r, self.record_class) for r in val]):
+        if isinstance(val, basestring):
+            return self._get_records_from_string(val)
+        elif not all([isinstance(r, self.record_class) for r in val]):
             msg = "List field must contain instances of '{}'.".format(self.record_class.__name__)
             raise TypeError(msg)
         return list(val)
